from footprint import Footprint

footprints = {
    'cubieboard': Footprint('Cubian', cpu_count=1),
    'cubieboard2': Footprint('Cubian', cpu_count=2, mem_size=847970304),
    'cubietruck': Footprint('Cubian', cpu_count=2, mem_size=1911201792),
    'raspberrypi': Footprint('raspberrypi'),
    'beagleboneblack': Footprint('arm')
}

titles = {
    'cubieboard': 'Cubieboard',
    'cubieboard2': 'Cubieboard2',
    'cubietruck': 'Cubietruck',
    'raspberrypi': 'Raspberry Pi Model B',
    'beagleboneblack': 'BeagleBone Black'
}